## Race Against Drift Diffusion (RADD) model
Contributors: [K. Dunovan](http://www.github.com/dunovank), [J. Huang](http://www.github.com/jeremyahuang), & [T. Verstynen](http://www.cognitiveaxon.com)

This repository is associated with the manuscript [Competing basal-ganglia pathways determine the difference between stopping and deciding not to go](http://www.elifesciences.org/content/4/e08723) and contains code and documentation for fitting various inhibitory control and decision models to behavioral data.

Click the "launch binder" button below to open up an interactive demo of radd in your browser (created using [binder](http://mybinder.org/)). Or view/download the demo notebook [here](https://nbviewer.jupyter.org/github/CoAxLab/radd/blob/dev/index.ipynb).

### Interactive Demo:
[![Binder](http://mybinder.org/badge.svg)](http://mybinder.org:/repo/coaxlab/radd)

### Install with pip
```sh
pip install radd
```
